summaryrefslogtreecommitdiffstats
path: root/kdeui/kbuttonbox.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-01-13 08:32:36 +0000
commitf7e71d47719ab6094cf4a9fafffa5ea351973522 (patch)
tree30834aa632d442019e14f88685001d94657d060b /kdeui/kbuttonbox.cpp
parentb31cfd9a1ee986fe2ae9a693f3afd7f171dd897c (diff)
downloadtdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.tar.gz
tdelibs-f7e71d47719ab6094cf4a9fafffa5ea351973522.zip
Initial conversion for TQt for Qt4 3.4.0 TP2
This will also compile with TQt for Qt3, and should not cause any problems with dependent modules such as kdebase. If it does then it needs to be fixed! git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1214149 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kdeui/kbuttonbox.cpp')
-rw-r--r--kdeui/kbuttonbox.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/kdeui/kbuttonbox.cpp b/kdeui/kbuttonbox.cpp
index eb0e27827..25bd6c71b 100644
--- a/kdeui/kbuttonbox.cpp
+++ b/kdeui/kbuttonbox.cpp
@@ -39,7 +39,7 @@
* which makes the buttons look better.
*
* 01/17/98 Mario Weilguni <mweilguni@sime.com>
* Fixed a bug in sizeHint()
* Improved the handling of Motif default buttons
*
* 01/09/98 Mario Weilguni <mweilguni@sime.com>
@@ -178,12 +178,12 @@ void KButtonBox::layout() {
++itr;
}
- setMinimumSize(sizeHint());
+ setMinimumSize(tqsizeHint());
}
void KButtonBox::placeButtons() {
- if(data->orientation == Horizontal) {
+ if(data->orientation == Qt::Horizontal) {
// calculate free size and stretches
int fs = width() - 2 * data->border;
int stretch = 0;
@@ -300,7 +300,7 @@ TQSize KButtonBox::bestButtonSize() const {
return s;
}
-TQSize KButtonBox::sizeHint() const {
+TQSize KButtonBox::tqsizeHint() const {
unsigned int dw;
if(data->buttons.isEmpty())
@@ -323,7 +323,7 @@ TQSize KButtonBox::sizeHint() const {
else
s = bs;
- if(data->orientation == Horizontal)
+ if(data->orientation == Qt::Horizontal)
dw += s.width();
else
dw += s.height();
@@ -335,7 +335,7 @@ TQSize KButtonBox::sizeHint() const {
++itr;
}
- if(data->orientation == Horizontal)
+ if(data->orientation == Qt::Horizontal)
return TQSize(dw, bs.height() + 2 * data->border);
else
return TQSize(bs.width() + 2 * data->border, dw);
@@ -344,7 +344,7 @@ TQSize KButtonBox::sizeHint() const {
TQSizePolicy KButtonBox::sizePolicy() const
{
- return data->orientation == Horizontal?
+ return data->orientation == Qt::Horizontal?
TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed ) :
TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Minimum );
}
@@ -355,8 +355,8 @@ TQSizePolicy KButtonBox::sizePolicy() const
* as minimum width
*/
TQSize KButtonBox::buttonSizeHint(TQPushButton *b) const {
- TQSize s = b->sizeHint();
- const TQSize ms = b->minimumSize();
+ TQSize s = b->tqsizeHint();
+ const TQSize ms = b->tqminimumSize();
if(s.width() < minButtonWidth)
s.setWidth(minButtonWidth);
@@ -39,7 +39,7 @@
*
* 01/17/98 Mario Weilguni <mweilguni@sime.com>
- * Fixed a bug in sizeHint()
+ * Fixed a bug in tqsizeHint()
* Improved the handling of Motif default buttons
*